==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/InfrastructureSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class InfrastructureSpecFluentImpl<A extends io.fabric8.openshift.api.model.InfrastructureSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.InfrastructureSpecFluent<A>{
  public InfrastructureSpecFluentImpl() {
  }
  public InfrastructureSpecFluentImpl(io.fabric8.openshift.api.model.InfrastructureSpec instance) {
    this.withCloudConfig(instance.getCloudConfig()); 
    this.withPlatformSpec(instance.getPlatformSpec()); 
  }
  private io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder cloudConfig;
  private io.fabric8.openshift.api.model.PlatformSpecBuilder platformSpec;
  
  /**
   * This method has been deprecated, please use method buildCloudConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapFileReference getCloudConfig() {
    return this.cloudConfig!=null?this.cloudConfig.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapFileReference buildCloudConfig() {
    return this.cloudConfig!=null?this.cloudConfig.build():null;
  }
  public A withCloudConfig(io.fabric8.openshift.api.model.ConfigMapFileReference cloudConfig) {
    _visitables.get("cloudConfig").remove(this.cloudConfig);
    if (cloudConfig!=null){ this.cloudConfig= new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder(cloudConfig); _visitables.get("cloudConfig").add(this.cloudConfig);} return (A) this;
  }
  public java.lang.Boolean hasCloudConfig() {
    return this.cloudConfig != null;
  }
  public A withNewCloudConfig(java.lang.String key,java.lang.String name) {
    return (A)withCloudConfig(new ConfigMapFileReference(key, name));
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfig() {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.CloudConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item) {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.CloudConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editCloudConfig() {
    return withNewCloudConfigLike(getCloudConfig());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfig() {
    return withNewCloudConfigLike(getCloudConfig() != null ? getCloudConfig(): new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item) {
    return withNewCloudConfigLike(getCloudConfig() != null ? getCloudConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPlatformSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PlatformSpec getPlatformSpec() {
    return this.platformSpec!=null?this.platformSpec.build():null;
  }
  public io.fabric8.openshift.api.model.PlatformSpec buildPlatformSpec() {
    return this.platformSpec!=null?this.platformSpec.build():null;
  }
  public A withPlatformSpec(io.fabric8.openshift.api.model.PlatformSpec platformSpec) {
    _visitables.get("platformSpec").remove(this.platformSpec);
    if (platformSpec!=null){ this.platformSpec= new io.fabric8.openshift.api.model.PlatformSpecBuilder(platformSpec); _visitables.get("platformSpec").add(this.platformSpec);} return (A) this;
  }
  public java.lang.Boolean hasPlatformSpec() {
    return this.platformSpec != null;
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpec() {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.PlatformSpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item) {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.PlatformSpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editPlatformSpec() {
    return withNewPlatformSpecLike(getPlatformSpec());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpec() {
    return withNewPlatformSpecLike(getPlatformSpec() != null ? getPlatformSpec(): new io.fabric8.openshift.api.model.PlatformSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item) {
    return withNewPlatformSpecLike(getPlatformSpec() != null ? getPlatformSpec(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    InfrastructureSpecFluentImpl that = (InfrastructureSpecFluentImpl) o;
    if (cloudConfig != null ? !cloudConfig.equals(that.cloudConfig) :that.cloudConfig != null) return false;
    if (platformSpec != null ? !platformSpec.equals(that.platformSpec) :that.platformSpec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cloudConfig,  platformSpec,  super.hashCode());
  }
  public class CloudConfigNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapFileReferenceFluentImpl<io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<N>> implements io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CloudConfigNestedImpl(io.fabric8.openshift.api.model.ConfigMapFileReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder(this, item);
    }
    CloudConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder builder;
    public N and() {
      return (N) InfrastructureSpecFluentImpl.this.withCloudConfig(builder.build());
    }
    public N endCloudConfig() {
      return and();
    }
    
  }
  public class PlatformSpecNestedImpl<N> extends io.fabric8.openshift.api.model.PlatformSpecFluentImpl<io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<N>> implements io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PlatformSpecNestedImpl(io.fabric8.openshift.api.model.PlatformSpec item) {
      this.builder = new io.fabric8.openshift.api.model.PlatformSpecBuilder(this, item);
    }
    PlatformSpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.PlatformSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.PlatformSpecBuilder builder;
    public N and() {
      return (N) InfrastructureSpecFluentImpl.this.withPlatformSpec(builder.build());
    }
    public N endPlatformSpec() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/InfrastructureSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class InfrastructureSpecFluentImpl<A extends io.fabric8.openshift.api.model.InfrastructureSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.InfrastructureSpecFluent<A>{
  public InfrastructureSpecFluentImpl() {
  }
  public InfrastructureSpecFluentImpl(io.fabric8.openshift.api.model.InfrastructureSpec instance) {
    this.withCloudConfig(instance.getCloudConfig()); 
    this.withPlatformSpec(instance.getPlatformSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder cloudConfig;
  private io.fabric8.openshift.api.model.PlatformSpecBuilder platformSpec;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCloudConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapFileReference getCloudConfig() {
    return this.cloudConfig!=null?this.cloudConfig.build():null;
  }
  public io.fabric8.openshift.api.model.ConfigMapFileReference buildCloudConfig() {
    return this.cloudConfig!=null?this.cloudConfig.build():null;
  }
  public A withCloudConfig(io.fabric8.openshift.api.model.ConfigMapFileReference cloudConfig) {
    _visitables.get("cloudConfig").remove(this.cloudConfig);
    if (cloudConfig!=null){ this.cloudConfig= new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder(cloudConfig); _visitables.get("cloudConfig").add(this.cloudConfig);} return (A) this;
  }
  public java.lang.Boolean hasCloudConfig() {
    return this.cloudConfig != null;
  }
  public A withNewCloudConfig(java.lang.String key,java.lang.String name) {
    return (A)withCloudConfig(new ConfigMapFileReference(key, name));
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfig() {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.CloudConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> withNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item) {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.CloudConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editCloudConfig() {
    return withNewCloudConfigLike(getCloudConfig());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfig() {
    return withNewCloudConfigLike(getCloudConfig() != null ? getCloudConfig(): new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<A> editOrNewCloudConfigLike(io.fabric8.openshift.api.model.ConfigMapFileReference item) {
    return withNewCloudConfigLike(getCloudConfig() != null ? getCloudConfig(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPlatformSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.PlatformSpec getPlatformSpec() {
    return this.platformSpec!=null?this.platformSpec.build():null;
  }
  public io.fabric8.openshift.api.model.PlatformSpec buildPlatformSpec() {
    return this.platformSpec!=null?this.platformSpec.build():null;
  }
  public A withPlatformSpec(io.fabric8.openshift.api.model.PlatformSpec platformSpec) {
    _visitables.get("platformSpec").remove(this.platformSpec);
    if (platformSpec!=null){ this.platformSpec= new io.fabric8.openshift.api.model.PlatformSpecBuilder(platformSpec); _visitables.get("platformSpec").add(this.platformSpec);} return (A) this;
  }
  public java.lang.Boolean hasPlatformSpec() {
    return this.platformSpec != null;
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpec() {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.PlatformSpecNestedImpl();
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> withNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item) {
    return new io.fabric8.openshift.api.model.InfrastructureSpecFluentImpl.PlatformSpecNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editPlatformSpec() {
    return withNewPlatformSpecLike(getPlatformSpec());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpec() {
    return withNewPlatformSpecLike(getPlatformSpec() != null ? getPlatformSpec(): new io.fabric8.openshift.api.model.PlatformSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<A> editOrNewPlatformSpecLike(io.fabric8.openshift.api.model.PlatformSpec item) {
    return withNewPlatformSpecLike(getPlatformSpec() != null ? getPlatformSpec(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    InfrastructureSpecFluentImpl that = (InfrastructureSpecFluentImpl) o;
    if (cloudConfig != null ? !cloudConfig.equals(that.cloudConfig) :that.cloudConfig != null) return false;
    if (platformSpec != null ? !platformSpec.equals(that.platformSpec) :that.platformSpec != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cloudConfig,  platformSpec,  additionalProperties,  super.hashCode());
  }
  public class CloudConfigNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapFileReferenceFluentImpl<io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<N>> implements io.fabric8.openshift.api.model.InfrastructureSpecFluent.CloudConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CloudConfigNestedImpl(io.fabric8.openshift.api.model.ConfigMapFileReference item) {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder(this, item);
    }
    CloudConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ConfigMapFileReferenceBuilder builder;
    public N and() {
      return (N) InfrastructureSpecFluentImpl.this.withCloudConfig(builder.build());
    }
    public N endCloudConfig() {
      return and();
    }
    
  }
  public class PlatformSpecNestedImpl<N> extends io.fabric8.openshift.api.model.PlatformSpecFluentImpl<io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<N>> implements io.fabric8.openshift.api.model.InfrastructureSpecFluent.PlatformSpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PlatformSpecNestedImpl(io.fabric8.openshift.api.model.PlatformSpec item) {
      this.builder = new io.fabric8.openshift.api.model.PlatformSpecBuilder(this, item);
    }
    PlatformSpecNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.PlatformSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.PlatformSpecBuilder builder;
    public N and() {
      return (N) InfrastructureSpecFluentImpl.this.withPlatformSpec(builder.build());
    }
    public N endPlatformSpec() {
      return and();
    }
    
  }
  
}
